@@ -76,91 +76,91 @@
 #Network Loadings
 net.loads <- function(A, wc, rm.zero = FALSE, plot = FALSE)
 {
-    # Detect if input is an 'EGA' object
-    if(class(A) == "EGA")
-    {
-        # Grab communities
-        wc <- A$wc
-        
-        # Replace 'A' with 'EGA' network
-        A <- A$network
-    }
+  # Detect if input is an 'EGA' object
+  if(class(A) == "EGA")
+  {
+    # Grab communities
+    wc <- A$wc
     
-    comc <- NetworkToolbox::comcat(A,comm=wc,metric="each",absolute=FALSE,diagonal=1)
-    stab <- NetworkToolbox::stable(A,comm=wc,absolute=FALSE,diagonal=1)
-    
-    for(q in 1:nrow(comc))
-    {comc[q,which(is.na(comc[q,]))] <- stab[q]}
+    # Replace 'A' with 'EGA' network
+    A <- A$network
+  }
+  
+  comc <- NetworkToolbox::comcat(A,comm=wc,metric="each",absolute=FALSE,diagonal=1)
+  stab <- NetworkToolbox::stable(A,comm=wc,absolute=FALSE,diagonal=1)
+  
+  for(q in 1:nrow(comc))
+  {comc[q,which(is.na(comc[q,]))] <- stab[q]}
+  
+  if(ncol(comc)!=1)
+  {
+    comm.str <- comc[,order(colnames(comc))]
+    comm.str <- round(comm.str,3)
+  }else{comm.str <- stab}
+  
+  #result list
+  res <- list()
+  
+  #unstandardized loadings
+  if(rm.zero)
+  {
+    comm.str <- as.data.frame(ifelse(comm.str==0,"",comm.str))
+    unstd <- apply(as.matrix(comm.str),2,as.numeric)
+    unstd <- ifelse(is.na(unstd),0,unstd)
+    row.names(comm.str) <- colnames(A)
+    res$unstd <- comm.str
     
+    #stardardized loadings
     if(ncol(comc)!=1)
-    {
-        comm.str <- comc[,order(colnames(comc))]
-        comm.str <- round(comm.str,3)
-    }else{comm.str <- comc}
+    {std <- t(t(unstd) / sqrt(colSums(unstd)))
+    }else{std <- t(t(unstd) / sqrt(sum(unstd)))}
     
-    #result list
-    res <- list()
+    std <- as.data.frame(ifelse(std==0,"",std))
     
-    #unstandardized loadings
-    if(rm.zero)
-    {
-        comm.str <- as.data.frame(ifelse(comm.str==0,"",comm.str))
-        unstd <- apply(as.matrix(comm.str),2,as.numeric)
-        unstd <- ifelse(is.na(unstd),0,unstd)
-        row.names(comm.str) <- colnames(A)
-        res$unstd <- comm.str
-        
-        #stardardized loadings
-        if(ncol(comc)!=1)
-        {std <- t(t(unstd) / sqrt(colSums(unstd)))
-        }else{std <- t(t(unstd) / sqrt(sum(unstd)))}
-        
-        std <- as.data.frame(ifelse(std==0,"",std))
-        
-        row.names(std) <- colnames(A)
-        
-        res$std <- std
-        
-    }else{
-        unstd <- apply(as.matrix(comm.str),2,as.numeric)
-        row.names(unstd) <- colnames(A)
-        res$unstd <- unstd
-        
-        #stardardized loadings
-        if(ncol(comc)!=1)
-        {std <- t(t(unstd) / sqrt(colSums(unstd)))
-        }else{std <- t(t(unstd) / sqrt(sum(unstd)))}
-        
-        row.names(std) <- colnames(A)
-        
-        res$std <- std
-    }
+    row.names(std) <- colnames(A)
     
-    #Plot?
-    if(plot)
-    {
-        #Set to absolute for multidimensional
-        std.res <- abs(res$std)
-        
-        #Standardize by maximum rspbc
-        std.res <- std.res / rowSums(std.res)
-        
-        #Ensure that pie value is not greater than 1
-        std.res <- std.res - .001
-        std.res <- ifelse(std.res==-.001,0,std.res)
-        
-        #Split results to list for each node
-        pies <- split(std.res, rep(1:nrow(std.res)))
-        
-        #Plot
-        qgraph::qgraph(A, layout = "spring",
-                       groups = as.factor(wc),
-                       label.prop = 1.5,
-                       pie = pies,
-                       vTrans = 200,
-                       negDashed = TRUE)
-    }
+    res$std <- std
     
-    return(res)
+  }else{
+    unstd <- apply(as.matrix(comm.str),2,as.numeric)
+    row.names(unstd) <- colnames(A)
+    res$unstd <- unstd
+    
+    #stardardized loadings
+    if(ncol(comc)!=1)
+    {std <- t(t(unstd) / sqrt(colSums(unstd)))
+    }else{std <- t(t(unstd) / sqrt(sum(unstd)))}
+    
+    row.names(std) <- colnames(A)
+    
+    res$std <- std
+  }
+  
+  #Plot?
+  if(plot)
+  {
+    #Set to absolute for multidimensional
+    std.res <- abs(res$std)
+    
+    #Standardize by maximum rspbc
+    std.res <- std.res / rowSums(std.res)
+    
+    #Ensure that pie value is not greater than 1
+    std.res <- std.res - .001
+    std.res <- ifelse(std.res==-.001,0,std.res)
+    
+    #Split results to list for each node
+    pies <- split(std.res, rep(1:nrow(std.res)))
+    
+    #Plot
+    qgraph::qgraph(A, layout = "spring",
+                   groups = as.factor(wc),
+                   label.prop = 1.5,
+                   pie = pies,
+                   vTrans = 200,
+                   negDashed = TRUE)
+  }
+  
+  return(res)
 }
-#----
\ No newline at end of file
+#----
